==> gnome-libs-1.0.12.tar.gz: gnome-libs-1.0.12/libgnomeui/gnome-druid-page-finish.h <==
/* gnome-druid-page-finish.h
 * Copyright (C) 1999  Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GNOME_DRUID_PAGE_FINISH_H__
#define __GNOME_DRUID_PAGE_FINISH_H__

#include <gtk/gtk.h>
#include <gdk_imlib.h>
#include "gnome-canvas.h"
#include "gnome-druid-page.h"
#ifdef __cplusplus
extern "C" {
#pragma }
#endif /* __cplusplus */

#define GNOME_TYPE_DRUID_PAGE_FINISH			(gnome_druid_page_finish_get_type ())
#define GNOME_DRUID_PAGE_FINISH(obj)			(GTK_CHECK_CAST ((obj), GNOME_TYPE_DRUID_PAGE_FINISH, GnomeDruidPageFinish))
#define GNOME_DRUID_PAGE_FINISH_CLASS(klass)		(GTK_CHECK_CLASS_CAST ((klass), GNOME_TYPE_DRUID_PAGE_FINISH, GnomeDruidPageFinishClass))
#define GNOME_IS_DRUID_PAGE_FINISH(obj)			(GTK_CHECK_TYPE ((obj), GNOME_TYPE_DRUID_PAGE_FINISH))
#define GNOME_IS_DRUID_PAGE_FINISH_CLASS(klass)		(GTK_CHECK_CLASS_TYPE ((obj), GNOME_TYPE_DRUID_PAGE_FINISH))


typedef struct _GnomeDruidPageFinish       GnomeDruidPageFinish;
typedef struct _GnomeDruidPageFinishClass  GnomeDruidPageFinishClass;

struct _GnomeDruidPageFinish
{
	GnomeDruidPage parent;

	GdkColor background_color;
	GdkColor textbox_color;
	GdkColor logo_background_color;
	GdkColor title_color;
	GdkColor text_color;

	gchar *title;
	gchar *text;
	GdkImlibImage *logo_image;
	GdkImlibImage *watermark_image;

	/*< private >*/
	GtkWidget *canvas;
	GnomeCanvasItem *background_item;
	GnomeCanvasItem *textbox_item;
	GnomeCanvasItem *text_item;
	GnomeCanvasItem *logo_item;
	GnomeCanvasItem *logoframe_item;
	GnomeCanvasItem *watermark_item;
	GnomeCanvasItem *title_item;
};
struct _GnomeDruidPageFinishClass
{
  GnomeDruidPageClass parent_class;
};


GtkType    gnome_druid_page_finish_get_type    (void);
GtkWidget *gnome_druid_page_finish_new         (void);
GtkWidget *gnome_druid_page_finish_new_with_vals(gchar *title,
					       gchar* text,
					       GdkImlibImage *logo,
					       GdkImlibImage *watermark);
void gnome_druid_page_finish_set_bg_color      (GnomeDruidPageFinish *druid_page_finish,
					       GdkColor *color);
void gnome_druid_page_finish_set_textbox_color (GnomeDruidPageFinish *druid_page_finish,
					       GdkColor *color);
void gnome_druid_page_finish_set_logo_bg_color (GnomeDruidPageFinish *druid_page_finish,
					       GdkColor *color);
void gnome_druid_page_finish_set_title_color   (GnomeDruidPageFinish *druid_page_finish,
					       GdkColor *color);
void gnome_druid_page_finish_set_text_color    (GnomeDruidPageFinish *druid_page_finish,
					       GdkColor *color);
void gnome_druid_page_finish_set_text          (GnomeDruidPageFinish *druid_page_finish,
					       gchar *text);
void gnome_druid_page_finish_set_title         (GnomeDruidPageFinish *druid_page_finish,
					       gchar *title);
void gnome_druid_page_finish_set_logo          (GnomeDruidPageFinish *druid_page_finish,
					       GdkImlibImage *logo_image);
void gnome_druid_page_finish_set_watermark     (GnomeDruidPageFinish *druid_page_finish,
					       GdkImlibImage *watermark);

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __GNOME_DRUID_PAGE_FINISH_H__ */

==> gnome-libs_1.0.56.orig.tar.gz: gnome-libs-1.0.56/libgnomeui/gnome-druid-page-finish.h <==
/* gnome-druid-page-finish.h
 * Copyright (C) 1999  Red Hat, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __GNOME_DRUID_PAGE_FINISH_H__
#define __GNOME_DRUID_PAGE_FINISH_H__

#include <gtk/gtk.h>
#include <gdk_imlib.h>
#include "gnome-canvas.h"
#include "gnome-druid-page.h"

BEGIN_GNOME_DECLS

#define GNOME_TYPE_DRUID_PAGE_FINISH			(gnome_druid_page_finish_get_type ())
#define GNOME_DRUID_PAGE_FINISH(obj)			(GTK_CHECK_CAST ((obj), GNOME_TYPE_DRUID_PAGE_FINISH, GnomeDruidPageFinish))
#define GNOME_DRUID_PAGE_FINISH_CLASS(klass)		(GTK_CHECK_CLASS_CAST ((klass), GNOME_TYPE_DRUID_PAGE_FINISH, GnomeDruidPageFinishClass))
#define GNOME_IS_DRUID_PAGE_FINISH(obj)			(GTK_CHECK_TYPE ((obj), GNOME_TYPE_DRUID_PAGE_FINISH))
#define GNOME_IS_DRUID_PAGE_FINISH_CLASS(klass)		(GTK_CHECK_CLASS_TYPE ((obj), GNOME_TYPE_DRUID_PAGE_FINISH))


typedef struct _GnomeDruidPageFinish       GnomeDruidPageFinish;
typedef struct _GnomeDruidPageFinishClass  GnomeDruidPageFinishClass;

struct _GnomeDruidPageFinish
{
	GnomeDruidPage parent;

	GdkColor background_color;
	GdkColor textbox_color;
	GdkColor logo_background_color;
	GdkColor title_color;
	GdkColor text_color;

	gchar *title;
	gchar *text;
	GdkImlibImage *logo_image;
	GdkImlibImage *watermark_image;

	/*< private >*/
	GtkWidget *canvas;
	GnomeCanvasItem *background_item;
	GnomeCanvasItem *textbox_item;
	GnomeCanvasItem *text_item;
	GnomeCanvasItem *logo_item;
	GnomeCanvasItem *logoframe_item;
	GnomeCanvasItem *watermark_item;
	GnomeCanvasItem *title_item;
};
struct _GnomeDruidPageFinishClass
{
  GnomeDruidPageClass parent_class;
};


GtkType    gnome_druid_page_finish_get_type    (void);
GtkWidget *gnome_druid_page_finish_new         (void);
GtkWidget *gnome_druid_page_finish_new_with_vals(const gchar *title,
					       const gchar* text,
					       GdkImlibImage *logo,
					       GdkImlibImage *watermark);
void gnome_druid_page_finish_set_bg_color      (GnomeDruidPageFinish *druid_page_finish,
					       GdkColor *color);
void gnome_druid_page_finish_set_textbox_color (GnomeDruidPageFinish *druid_page_finish,
					       GdkColor *color);
void gnome_druid_page_finish_set_logo_bg_color (GnomeDruidPageFinish *druid_page_finish,
					       GdkColor *color);
void gnome_druid_page_finish_set_title_color   (GnomeDruidPageFinish *druid_page_finish,
					       GdkColor *color);
void gnome_druid_page_finish_set_text_color    (GnomeDruidPageFinish *druid_page_finish,
					       GdkColor *color);
void gnome_druid_page_finish_set_text          (GnomeDruidPageFinish *druid_page_finish,
					       const gchar *text);
void gnome_druid_page_finish_set_title         (GnomeDruidPageFinish *druid_page_finish,
					       const gchar *title);
void gnome_druid_page_finish_set_logo          (GnomeDruidPageFinish *druid_page_finish,
					       GdkImlibImage *logo_image);
void gnome_druid_page_finish_set_watermark     (GnomeDruidPageFinish *druid_page_finish,
					       GdkImlibImage *watermark);

END_GNOME_DECLS

#endif /* __GNOME_DRUID_PAGE_FINISH_H__ */
